# -*- coding: utf-8 -*-
info = {
    "name": "is",
    "date_order": "DMY",
    "january": [
        "janúar",
        "jan"
    ],
    "february": [
        "febrúar",
        "feb"
    ],
    "march": [
        "mars",
        "mar"
    ],
    "april": [
        "apríl",
        "apr"
    ],
    "may": [
        "maí"
    ],
    "june": [
        "júní",
        "jún"
    ],
    "july": [
        "júlí",
        "júl"
    ],
    "august": [
        "ágúst",
        "ágú"
    ],
    "september": [
        "september",
        "sep"
    ],
    "october": [
        "október",
        "okt"
    ],
    "november": [
        "nóvember",
        "nóv"
    ],
    "december": [
        "desember",
        "des"
    ],
    "monday": [
        "mánudagur",
        "mán"
    ],
    "tuesday": [
        "þriðjudagur",
        "þri"
    ],
    "wednesday": [
        "miðvikudagur",
        "mið"
    ],
    "thursday": [
        "fimmtudagur",
        "fim"
    ],
    "friday": [
        "föstudagur",
        "fös"
    ],
    "saturday": [
        "laugardagur",
        "lau"
    ],
    "sunday": [
        "sunnudagur",
        "sun"
    ],
    "am": [
        "fh"
    ],
    "pm": [
        "eh"
    ],
    "year": [
        "ár"
    ],
    "month": [
        "mánuður",
        "mán"
    ],
    "week": [
        "vika",
        "v"
    ],
    "day": [
        "dagur",
        "d"
    ],
    "hour": [
        "klukkustund",
        "klst"
    ],
    "minute": [
        "mínúta",
        "mín"
    ],
    "second": [
        "sekúnda",
        "sek"
    ],
    "relative-type": {
        "1 year ago": [
            "á síðasta ári"
        ],
        "0 year ago": [
            "á þessu ári"
        ],
        "in 1 year": [
            "á næsta ári"
        ],
        "1 month ago": [
            "í síðasta mánuði",
            "í síðasta mán"
        ],
        "0 month ago": [
            "í þessum mánuði",
            "í þessum mán"
        ],
        "in 1 month": [
            "í næsta mánuði",
            "í næsta mán"
        ],
        "1 week ago": [
            "í síðustu viku"
        ],
        "0 week ago": [
            "í þessari viku"
        ],
        "in 1 week": [
            "í næstu viku"
        ],
        "1 day ago": [
            "í gær"
        ],
        "0 day ago": [
            "í dag"
        ],
        "in 1 day": [
            "á morgun"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "núna"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "eftir (\\d+) ár"
        ],
        "\\1 year ago": [
            "fyrir (\\d+) ári",
            "fyrir (\\d+) árum"
        ],
        "in \\1 month": [
            "eftir (\\d+) mánuð",
            "eftir (\\d+) mánuði",
            "eftir (\\d+) mán"
        ],
        "\\1 month ago": [
            "fyrir (\\d+) mánuði",
            "fyrir (\\d+) mánuðum",
            "fyrir (\\d+) mán"
        ],
        "in \\1 week": [
            "eftir (\\d+) viku",
            "eftir (\\d+) vikur"
        ],
        "\\1 week ago": [
            "fyrir (\\d+) viku",
            "fyrir (\\d+) vikum"
        ],
        "in \\1 day": [
            "eftir (\\d+) dag",
            "eftir (\\d+) daga"
        ],
        "\\1 day ago": [
            "fyrir (\\d+) degi",
            "fyrir (\\d+) dögum"
        ],
        "in \\1 hour": [
            "eftir (\\d+) klukkustund",
            "eftir (\\d+) klukkustundir",
            "eftir (\\d+) klst"
        ],
        "\\1 hour ago": [
            "fyrir (\\d+) klukkustund",
            "fyrir (\\d+) klukkustundum",
            "fyrir (\\d+) klst"
        ],
        "in \\1 minute": [
            "eftir (\\d+) mínútu",
            "eftir (\\d+) mínútur",
            "eftir (\\d+) mín"
        ],
        "\\1 minute ago": [
            "fyrir (\\d+) mínútu",
            "fyrir (\\d+) mínútum",
            "fyrir (\\d+) mín"
        ],
        "in \\1 second": [
            "eftir (\\d+) sekúndu",
            "eftir (\\d+) sekúndur",
            "eftir (\\d+) sek"
        ],
        "\\1 second ago": [
            "fyrir (\\d+) sekúndu",
            "fyrir (\\d+) sekúndum",
            "fyrir (\\d+) sek"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}