# -*- coding: utf-8 -*-
info = {
    "name": "xog",
    "date_order": "DMY",
    "january": [
        "janwaliyo",
        "jan"
    ],
    "february": [
        "febwaliyo",
        "feb"
    ],
    "march": [
        "marisi",
        "mar"
    ],
    "april": [
        "apuli",
        "apu"
    ],
    "may": [
        "maayi",
        "maa"
    ],
    "june": [
        "juuni",
        "juu"
    ],
    "july": [
        "julaayi",
        "jul"
    ],
    "august": [
        "agusito",
        "agu"
    ],
    "september": [
        "sebuttemba",
        "seb"
    ],
    "october": [
        "okitobba",
        "oki"
    ],
    "november": [
        "novemba",
        "nov"
    ],
    "december": [
        "desemba",
        "des"
    ],
    "monday": [
        "balaza",
        "bala"
    ],
    "tuesday": [
        "owokubili",
        "kubi"
    ],
    "wednesday": [
        "owokusatu",
        "kusa"
    ],
    "thursday": [
        "olokuna",
        "kuna"
    ],
    "friday": [
        "olokutaanu",
        "kuta"
    ],
    "saturday": [
        "olomukaaga",
        "muka"
    ],
    "sunday": [
        "sabiiti",
        "sabi"
    ],
    "am": [
        "munkyo"
    ],
    "pm": [
        "eigulo"
    ],
    "year": [
        "omwaka"
    ],
    "month": [
        "omwezi"
    ],
    "week": [
        "esabiiti"
    ],
    "day": [
        "olunaku"
    ],
    "hour": [
        "essawa"
    ],
    "minute": [
        "edakiika"
    ],
    "second": [
        "obutikitiki"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "edho"
        ],
        "0 day ago": [
            "olwaleelo (leelo)"
        ],
        "in 1 day": [
            "enkyo"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}