# -*- coding: utf-8 -*-
info = {
    "name": "lb",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan"
    ],
    "february": [
        "februar",
        "feb"
    ],
    "march": [
        "mäerz",
        "mäe"
    ],
    "april": [
        "abrëll",
        "abr"
    ],
    "may": [
        "mee"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "juli",
        "jul"
    ],
    "august": [
        "august",
        "aug"
    ],
    "september": [
        "september",
        "sep"
    ],
    "october": [
        "oktober",
        "okt"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "dezember",
        "dez"
    ],
    "monday": [
        "méindeg",
        "méi"
    ],
    "tuesday": [
        "dënschdeg",
        "dën"
    ],
    "wednesday": [
        "mëttwoch",
        "mët"
    ],
    "thursday": [
        "donneschdeg",
        "don"
    ],
    "friday": [
        "freideg",
        "fre"
    ],
    "saturday": [
        "samschdeg",
        "sam"
    ],
    "sunday": [
        "sonndeg",
        "son"
    ],
    "am": [
        "moies"
    ],
    "pm": [
        "nomëttes"
    ],
    "year": [
        "joer",
        "j"
    ],
    "month": [
        "mount",
        "m"
    ],
    "week": [
        "woch",
        "w"
    ],
    "day": [
        "dag",
        "d"
    ],
    "hour": [
        "stonn",
        "st"
    ],
    "minute": [
        "minutt",
        "min"
    ],
    "second": [
        "sekonn",
        "sek"
    ],
    "relative-type": {
        "1 year ago": [
            "lescht joer"
        ],
        "0 year ago": [
            "dëst joer"
        ],
        "in 1 year": [
            "nächst joer"
        ],
        "1 month ago": [
            "leschte mount"
        ],
        "0 month ago": [
            "dëse mount"
        ],
        "in 1 month": [
            "nächste mount"
        ],
        "1 week ago": [
            "lescht woch"
        ],
        "0 week ago": [
            "dës woch"
        ],
        "in 1 week": [
            "nächst woch"
        ],
        "1 day ago": [
            "gëschter"
        ],
        "0 day ago": [
            "haut"
        ],
        "in 1 day": [
            "muer"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "an (\\d+) joer",
            "an (\\d+) j"
        ],
        "\\1 year ago": [
            "virun (\\d+) joer",
            "virun (\\d+) j"
        ],
        "in \\1 month": [
            "an (\\d+) mount",
            "an (\\d+) m"
        ],
        "\\1 month ago": [
            "virun (\\d+) mount",
            "virun (\\d+) m"
        ],
        "in \\1 week": [
            "an (\\d+) woch",
            "an (\\d+) w"
        ],
        "\\1 week ago": [
            "virun (\\d+) woch",
            "virun (\\d+) w"
        ],
        "in \\1 day": [
            "an (\\d+) dag",
            "an (\\d+) d"
        ],
        "\\1 day ago": [
            "virun (\\d+) dag",
            "virun (\\d+) d"
        ],
        "in \\1 hour": [
            "an (\\d+) stonn",
            "an (\\d+) st"
        ],
        "\\1 hour ago": [
            "virun (\\d+) stonn",
            "virun (\\d+) st"
        ],
        "in \\1 minute": [
            "an (\\d+) minutt",
            "an (\\d+) min"
        ],
        "\\1 minute ago": [
            "virun (\\d+) minutt",
            "virun (\\d+) min"
        ],
        "in \\1 second": [
            "an (\\d+) sekonn",
            "an (\\d+) sek"
        ],
        "\\1 second ago": [
            "virun (\\d+) sekonn",
            "virun (\\d+) sek"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}