# -*- coding: utf-8 -*-
info = {
    "name": "uz-Latn",
    "date_order": "DMY",
    "january": [
        "yanvar",
        "yan"
    ],
    "february": [
        "fevral",
        "fev"
    ],
    "march": [
        "mart",
        "mar"
    ],
    "april": [
        "aprel",
        "apr"
    ],
    "may": [
        "may"
    ],
    "june": [
        "iyun",
        "iyn"
    ],
    "july": [
        "iyul",
        "iyl"
    ],
    "august": [
        "avgust",
        "avg"
    ],
    "september": [
        "sentabr",
        "sen"
    ],
    "october": [
        "oktabr",
        "okt"
    ],
    "november": [
        "noyabr",
        "noy"
    ],
    "december": [
        "dekabr",
        "dek"
    ],
    "monday": [
        "dushanba",
        "dush"
    ],
    "tuesday": [
        "seshanba",
        "sesh"
    ],
    "wednesday": [
        "chorshanba",
        "chor"
    ],
    "thursday": [
        "payshanba",
        "pay"
    ],
    "friday": [
        "juma",
        "jum"
    ],
    "saturday": [
        "shanba",
        "shan"
    ],
    "sunday": [
        "yakshanba",
        "yak"
    ],
    "am": [
        "to"
    ],
    "pm": [
        "tk"
    ],
    "year": [
        "yil"
    ],
    "month": [
        "oy"
    ],
    "week": [
        "hafta"
    ],
    "day": [
        "kun"
    ],
    "hour": [
        "soat"
    ],
    "minute": [
        "daqiqa",
        "daq"
    ],
    "second": [
        "soniya",
        "son"
    ],
    "relative-type": {
        "1 year ago": [
            "o‘tgan yil",
            "o'tgan yil"
        ],
        "0 year ago": [
            "shu yil",
            "bu yil"
        ],
        "in 1 year": [
            "keyingi yil"
        ],
        "1 month ago": [
            "o‘tgan oy"
        ],
        "0 month ago": [
            "shu oy"
        ],
        "in 1 month": [
            "keyingi oy"
        ],
        "1 week ago": [
            "o‘tgan hafta"
        ],
        "0 week ago": [
            "shu hafta"
        ],
        "in 1 week": [
            "keyingi hafta"
        ],
        "1 day ago": [
            "kecha"
        ],
        "0 day ago": [
            "bugun"
        ],
        "in 1 day": [
            "ertaga"
        ],
        "0 hour ago": [
            "shu soatda"
        ],
        "0 minute ago": [
            "shu daqiqada"
        ],
        "0 second ago": [
            "hozir"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) yildan keyin"
        ],
        "\\1 year ago": [
            "(\\d+) yil oldin"
        ],
        "in \\1 month": [
            "(\\d+) oydan keyin"
        ],
        "\\1 month ago": [
            "(\\d+) oy oldin"
        ],
        "in \\1 week": [
            "(\\d+) haftadan keyin"
        ],
        "\\1 week ago": [
            "(\\d+) hafta oldin"
        ],
        "in \\1 day": [
            "(\\d+) kundan keyin"
        ],
        "\\1 day ago": [
            "(\\d+) kun oldin"
        ],
        "in \\1 hour": [
            "(\\d+) soatdan keyin"
        ],
        "\\1 hour ago": [
            "(\\d+) soat oldin"
        ],
        "in \\1 minute": [
            "(\\d+) daqiqadan keyin"
        ],
        "\\1 minute ago": [
            "(\\d+) daqiqa oldin"
        ],
        "in \\1 second": [
            "(\\d+) soniyadan keyin"
        ],
        "\\1 second ago": [
            "(\\d+) soniya oldin"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}