# -*- coding: utf-8 -*-
info = {
    "name": "tzm",
    "date_order": "DMY",
    "january": [
        "yennayer",
        "yen"
    ],
    "february": [
        "yebrayer",
        "yeb"
    ],
    "march": [
        "mars",
        "mar"
    ],
    "april": [
        "ibrir",
        "ibr"
    ],
    "may": [
        "mayyu",
        "may"
    ],
    "june": [
        "yunyu",
        "yun"
    ],
    "july": [
        "yulyuz",
        "yul"
    ],
    "august": [
        "ɣuct",
        "ɣuc"
    ],
    "september": [
        "cutanbir",
        "cut"
    ],
    "october": [
        "kṭuber",
        "kṭu"
    ],
    "november": [
        "nwanbir",
        "nwa"
    ],
    "december": [
        "dujanbir",
        "duj"
    ],
    "monday": [
        "aynas",
        "ayn"
    ],
    "tuesday": [
        "asinas",
        "asn"
    ],
    "wednesday": [
        "akras",
        "akr"
    ],
    "thursday": [
        "akwas",
        "akw"
    ],
    "friday": [
        "asimwas",
        "asm"
    ],
    "saturday": [
        "asiḍyas",
        "asḍ"
    ],
    "sunday": [
        "asamas",
        "asa"
    ],
    "am": [
        "zdat azal"
    ],
    "pm": [
        "ḍeffir aza"
    ],
    "year": [
        "asseggas"
    ],
    "month": [
        "ayur"
    ],
    "week": [
        "imalass"
    ],
    "day": [
        "ass"
    ],
    "hour": [
        "tasragt"
    ],
    "minute": [
        "tusdat"
    ],
    "second": [
        "tusnat"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "assenaṭ"
        ],
        "0 day ago": [
            "assa"
        ],
        "in 1 day": [
            "asekka"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}