# -*- coding: utf-8 -*-
info = {
    "name": "naq",
    "date_order": "DMY",
    "january": [
        "ǃkhanni",
        "jan"
    ],
    "february": [
        "ǃkhanǀgôab",
        "feb"
    ],
    "march": [
        "ǀkhuuǁkhâb",
        "mar"
    ],
    "april": [
        "ǃhôaǂkhaib",
        "apr"
    ],
    "may": [
        "ǃkhaitsâb",
        "may"
    ],
    "june": [
        "gamaǀaeb",
        "jun"
    ],
    "july": [
        "ǂkhoesaob",
        "jul"
    ],
    "august": [
        "aoǁkhuumûǁkhâb",
        "aug"
    ],
    "september": [
        "taraǀkhuumûǁkhâb",
        "sep"
    ],
    "october": [
        "ǂnûǁnâiseb",
        "oct"
    ],
    "november": [
        "ǀhooǂgaeb",
        "nov"
    ],
    "december": [
        "hôasoreǁkhâb",
        "dec"
    ],
    "monday": [
        "mantaxtsees",
        "ma"
    ],
    "tuesday": [
        "denstaxtsees",
        "de"
    ],
    "wednesday": [
        "wunstaxtsees",
        "wu"
    ],
    "thursday": [
        "dondertaxtsees",
        "do"
    ],
    "friday": [
        "fraitaxtsees",
        "fr"
    ],
    "saturday": [
        "satertaxtsees",
        "sat"
    ],
    "sunday": [
        "sontaxtsees",
        "son"
    ],
    "am": [
        "ǁgoagas"
    ],
    "pm": [
        "ǃuias"
    ],
    "year": [
        "kurib"
    ],
    "month": [
        "ǁkhâb"
    ],
    "week": [
        "wekheb"
    ],
    "day": [
        "tsees"
    ],
    "hour": [
        "iiri"
    ],
    "minute": [
        "haib"
    ],
    "second": [
        "ǀgâub"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "0 day ago": [
            "neetsee"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}