# -*- coding: utf-8 -*-
info = {
    "name": "mn",
    "date_order": "YMD",
    "january": [
        "нэгдүгээр сар",
        "1-р сар"
    ],
    "february": [
        "хоёрдугаар сар",
        "2-р сар"
    ],
    "march": [
        "гуравдугаар сар",
        "3-р сар"
    ],
    "april": [
        "дөрөвдүгээр сар",
        "4-р сар"
    ],
    "may": [
        "тавдугаар сар",
        "5-р сар"
    ],
    "june": [
        "зургадугаар сар",
        "6-р сар"
    ],
    "july": [
        "долдугаар сар",
        "7-р сар"
    ],
    "august": [
        "наймдугаар сар",
        "8-р сар"
    ],
    "september": [
        "есдүгээр сар",
        "9-р сар"
    ],
    "october": [
        "аравдугаар сар",
        "10-р сар"
    ],
    "november": [
        "арван нэгдүгээр сар",
        "11-р сар"
    ],
    "december": [
        "арван хоёрдугаар сар",
        "12-р сар"
    ],
    "monday": [
        "даваа",
        "да"
    ],
    "tuesday": [
        "мягмар",
        "мя"
    ],
    "wednesday": [
        "лхагва",
        "лх"
    ],
    "thursday": [
        "пүрэв",
        "пү"
    ],
    "friday": [
        "баасан",
        "ба"
    ],
    "saturday": [
        "бямба",
        "бя"
    ],
    "sunday": [
        "ням",
        "ня"
    ],
    "am": [
        "үө"
    ],
    "pm": [
        "үх"
    ],
    "year": [
        "жил"
    ],
    "month": [
        "сар"
    ],
    "week": [
        "долоо хоног",
        "7х"
    ],
    "day": [
        "өдөр"
    ],
    "hour": [
        "цаг",
        "ц"
    ],
    "minute": [
        "минут",
        "мин"
    ],
    "second": [
        "секунд",
        "сек"
    ],
    "relative-type": {
        "1 year ago": [
            "өнгөрсөн жил"
        ],
        "0 year ago": [
            "энэ жил"
        ],
        "in 1 year": [
            "ирэх жил"
        ],
        "1 month ago": [
            "өнгөрсөн сар"
        ],
        "0 month ago": [
            "энэ сар"
        ],
        "in 1 month": [
            "ирэх сар"
        ],
        "1 week ago": [
            "өнгөрсөн долоо хоног"
        ],
        "0 week ago": [
            "энэ долоо хоног"
        ],
        "in 1 week": [
            "ирэх долоо хоног"
        ],
        "1 day ago": [
            "өчигдөр"
        ],
        "0 day ago": [
            "өнөөдөр"
        ],
        "in 1 day": [
            "маргааш"
        ],
        "0 hour ago": [
            "энэ цаг"
        ],
        "0 minute ago": [
            "энэ минут"
        ],
        "0 second ago": [
            "одоо"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) жилийн дараа"
        ],
        "\\1 year ago": [
            "(\\d+) жилийн өмнө"
        ],
        "in \\1 month": [
            "(\\d+) сарын дараа"
        ],
        "\\1 month ago": [
            "(\\d+) сарын өмнө"
        ],
        "in \\1 week": [
            "(\\d+) 7х-ийн дараа"
        ],
        "\\1 week ago": [
            "(\\d+) 7х-ийн өмнө"
        ],
        "in \\1 day": [
            "(\\d+) өдрийн дараа",
            "(\\d+) өдөрт"
        ],
        "\\1 day ago": [
            "(\\d+) өдрийн өмнө"
        ],
        "in \\1 hour": [
            "(\\d+) цагийн дараа",
            "(\\d+) ц дараа"
        ],
        "\\1 hour ago": [
            "(\\d+) цагийн өмнө",
            "(\\d+) ц өмнө"
        ],
        "in \\1 minute": [
            "(\\d+) минутын дараа",
            "(\\d+) мин дараа"
        ],
        "\\1 minute ago": [
            "(\\d+) минутын өмнө",
            "(\\d+) мин өмнө"
        ],
        "in \\1 second": [
            "(\\d+) секундын дараа",
            "(\\d+) сек дараа"
        ],
        "\\1 second ago": [
            "(\\d+) секундын өмнө",
            "(\\d+) сек өмнө"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}