# -*- coding: utf-8 -*-
info = {
    "name": "mfe",
    "date_order": "DMY",
    "january": [
        "zanvie",
        "zan"
    ],
    "february": [
        "fevriye",
        "fev"
    ],
    "march": [
        "mars",
        "mar"
    ],
    "april": [
        "avril",
        "avr"
    ],
    "may": [
        "me"
    ],
    "june": [
        "zin"
    ],
    "july": [
        "zilye",
        "zil"
    ],
    "august": [
        "out"
    ],
    "september": [
        "septam",
        "sep"
    ],
    "october": [
        "oktob",
        "okt"
    ],
    "november": [
        "novam",
        "nov"
    ],
    "december": [
        "desam",
        "des"
    ],
    "monday": [
        "lindi",
        "lin"
    ],
    "tuesday": [
        "mardi",
        "mar"
    ],
    "wednesday": [
        "merkredi",
        "mer"
    ],
    "thursday": [
        "zedi",
        "ze"
    ],
    "friday": [
        "vandredi",
        "van"
    ],
    "saturday": [
        "samdi",
        "sam"
    ],
    "sunday": [
        "dimans",
        "dim"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "lane"
    ],
    "month": [
        "mwa"
    ],
    "week": [
        "semenn"
    ],
    "day": [
        "zour"
    ],
    "hour": [
        "ler"
    ],
    "minute": [
        "minit"
    ],
    "second": [
        "segonn"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "yer"
        ],
        "0 day ago": [
            "zordi"
        ],
        "in 1 day": [
            "demin"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}