# -*- coding: utf-8 -*-
info = {
    "name": "dyo",
    "date_order": "DMY",
    "january": [
        "sanvie",
        "sa"
    ],
    "february": [
        "fébirie",
        "fe"
    ],
    "march": [
        "mars",
        "ma"
    ],
    "april": [
        "aburil",
        "ab"
    ],
    "may": [
        "mee",
        "me"
    ],
    "june": [
        "sueŋ",
        "su"
    ],
    "july": [
        "súuyee",
        "sú"
    ],
    "august": [
        "ut"
    ],
    "september": [
        "settembar",
        "se"
    ],
    "october": [
        "oktobar",
        "ok"
    ],
    "november": [
        "novembar",
        "no"
    ],
    "december": [
        "disambar",
        "de"
    ],
    "monday": [
        "teneŋ",
        "ten"
    ],
    "tuesday": [
        "talata",
        "tal"
    ],
    "wednesday": [
        "alarbay",
        "ala"
    ],
    "thursday": [
        "aramisay",
        "ara"
    ],
    "friday": [
        "arjuma",
        "arj"
    ],
    "saturday": [
        "sibiti",
        "sib"
    ],
    "sunday": [
        "dimas",
        "dim"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "emit"
    ],
    "month": [
        "fuleeŋ"
    ],
    "week": [
        "lóokuŋ"
    ],
    "day": [
        "funak"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "fucen"
        ],
        "0 day ago": [
            "jaat"
        ],
        "in 1 day": [
            "kajom"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}