# -*- coding: utf-8 -*-
info = {
    "name": "shi-Latn",
    "date_order": "DMY",
    "january": [
        "innayr",
        "inn"
    ],
    "february": [
        "bṛayṛ",
        "bṛa"
    ],
    "march": [
        "maṛṣ",
        "maṛ"
    ],
    "april": [
        "ibrir",
        "ibr"
    ],
    "may": [
        "mayyu",
        "may"
    ],
    "june": [
        "yunyu",
        "yun"
    ],
    "july": [
        "yulyuz",
        "yul"
    ],
    "august": [
        "ɣuct",
        "ɣuc"
    ],
    "september": [
        "cutanbir",
        "cut"
    ],
    "october": [
        "ktubr",
        "ktu"
    ],
    "november": [
        "nuwanbir",
        "nuw"
    ],
    "december": [
        "dujanbir",
        "duj"
    ],
    "monday": [
        "aynas",
        "ayn"
    ],
    "tuesday": [
        "asinas",
        "asi"
    ],
    "wednesday": [
        "akṛas",
        "akṛ"
    ],
    "thursday": [
        "akwas",
        "akw"
    ],
    "friday": [
        "asimwas",
        "asim"
    ],
    "saturday": [
        "asiḍyas",
        "asiḍ"
    ],
    "sunday": [
        "asamas",
        "asa"
    ],
    "am": [
        "tifawt"
    ],
    "pm": [
        "tadggʷat"
    ],
    "year": [
        "asggʷas"
    ],
    "month": [
        "ayyur"
    ],
    "week": [
        "imalass"
    ],
    "day": [
        "ass"
    ],
    "hour": [
        "tasragt"
    ],
    "minute": [
        "tusdidt"
    ],
    "second": [
        "tasint"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "iḍlli"
        ],
        "0 day ago": [
            "assa"
        ],
        "in 1 day": [
            "askka"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}