# -*- coding: utf-8 -*-
info = {
    "%%spellout-cardinal-feminine-ones": {
        "1": "jeden;",
        "(2, 'inf')": "=%spellout-cardinal-feminine=;"
    },
    "%%spellout-cardinal-genitive-tens": {
        "1": "dziesięciu;",
        "2": "dwudziestu;",
        "3": "trzydziestu;",
        "4": "czterdziestu;",
        "5": "pięćdziesięciu;",
        "6": "sześćdziesięciu;",
        "7": "siedemdziesięciu;",
        "8": "osiemdziesięciu;",
        "(9, 'inf')": "dziewięćdziesięciu;"
    },
    "%%spellout-cardinal-masculine-dative-ones": {
        "1": "jeden;",
        "(2, 'inf')": "=%spellout-cardinal-masculine-dative=;"
    },
    "%%spellout-cardinal-masculine-genitive-ones": {
        "1": "jeden;",
        "(2, 'inf')": "=%spellout-cardinal-masculine-genitive=;"
    },
    "%%spellout-cardinal-masculine-instrumental-ones": {
        "1": "jeden;",
        "(2, 'inf')": "=%spellout-cardinal-masculine-instrumental=;"
    },
    "%%spellout-cardinal-masculine-locative-ones": {
        "1": "jeden;",
        "(2, 'inf')": "=%spellout-cardinal-masculine-locative=;"
    },
    "%%spellout-cardinal-tens": {
        "1": "dziesięć;",
        "2": "dwadzieścia;",
        "3": "trzydzieści;",
        "4": "czterdzieści;",
        "5": "pięćdziesiąt;",
        "6": "sześćdziesiąt;",
        "7": "siedemdziesiąt;",
        "8": "osiemdziesiąt;",
        "(9, 'inf')": "dziewięćdziesiąt;"
    },
    "%%spellout-fraction": {
        "(10, 99)": "<%spellout-cardinal-masculine<<;",
        "(100, 999)": "<%spellout-cardinal-masculine<<;",
        "(1000, 9999)": "<%spellout-cardinal-masculine<<;",
        "(10000, 99999)": "<%%spellout-fraction-digits<<;",
        "(100000, 999999)": "<%%spellout-fraction-digits<<;",
        "(1000000, 9999999)": "<%%spellout-fraction-digits<<;",
        "(10000000, 99999999)": "<%%spellout-fraction-digits<<;",
        "(100000000, 999999999)": "<%%spellout-fraction-digits<<;",
        "(1000000000, 9999999999)": "<%%spellout-fraction-digits<<;",
        "(10000000000, 'inf')": "<0<;"
    },
    "%%spellout-fraction-digits": {
        "(0, 9)": "=%spellout-cardinal-masculine=;",
        "(10, 'inf')": "<< >>;"
    },
    "%spellout-cardinal-feminine": {
        "0": "zero;",
        "1": "jedna;",
        "2": "dwie;",
        "3": "trzy;",
        "4": "cztery;",
        "5": "pięć;",
        "6": "sześć;",
        "7": "siedem;",
        "8": "osiem;",
        "9": "dziewięć;",
        "10": "dziesięć;",
        "11": "jedenaście;",
        "12": "dwanaście;",
        "13": "trzynaście;",
        "14": "czternaście;",
        "15": "piętnaście;",
        "16": "szesnaście;",
        "17": "siedemnaście;",
        "18": "osiemnaście;",
        "19": "dziewiętnaście;",
        "(20, 99)": "<%%spellout-cardinal-tens<[ >%%spellout-cardinal-feminine-ones>];",
        "(100, 199)": "sto[ >%%spellout-cardinal-feminine-ones>];",
        "(200, 299)": "dwieście[ >%%spellout-cardinal-feminine-ones>];",
        "(300, 499)": "<%spellout-cardinal-feminine<sta[ >%%spellout-cardinal-feminine-ones>];",
        "(500, 999)": "<%spellout-cardinal-feminine<set[ >%%spellout-cardinal-feminine-ones>];",
        "(1000, 1999)": "tysiąc[ >%%spellout-cardinal-feminine-ones>];",
        "(2000, 999999)": "<%spellout-cardinal-masculine< $(cardinal,few{tysiące}other{tysięcy})$[ >%%spellout-cardinal-feminine-ones>];",
        "(1000000, 1999999)": "milion[ >%%spellout-cardinal-feminine-ones>];",
        "(2000000, 999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{miliony}other{milionów})$[ >%%spellout-cardinal-feminine-ones>];",
        "(1000000000, 1999999999)": "miliard[ >>];",
        "(2000000000, 999999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{miliardy}other{miliardów})$[ >%%spellout-cardinal-feminine-ones>];",
        "(1000000000000, 1999999999999)": "bilion[ >>];",
        "(2000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{biliony}other{bilionów})$[ >%%spellout-cardinal-feminine-ones>];",
        "(1000000000000000, 1999999999999999)": "biliard[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{biliardy}other{biliardów})$[ >%%spellout-cardinal-feminine-ones>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-feminine-accusative": {
        "0": "zero;",
        "1": "jedną;",
        "(2, 'inf')": "=%spellout-cardinal-feminine=;"
    },
    "%spellout-cardinal-feminine-dative": {
        "0": "zeru;",
        "1": "jednej;",
        "(2, 'inf')": "=%spellout-cardinal-masculine-dative=;"
    },
    "%spellout-cardinal-feminine-genitive": {
        "0": "zera;",
        "1": "jednej;",
        "(2, 'inf')": "=%spellout-cardinal-masculine-genitive=;"
    },
    "%spellout-cardinal-feminine-instrumental": {
        "0": "zerem;",
        "1": "jedną;",
        "2": "dwiema;",
        "(3, 'inf')": "=%spellout-cardinal-masculine-instrumental=;"
    },
    "%spellout-cardinal-feminine-locative": {
        "0": "zerze;",
        "1": "jednej;",
        "(2, 'inf')": "=%spellout-cardinal-masculine-locative=;"
    },
    "%spellout-cardinal-masculine": {
        "0": "zero;",
        "1": "jeden;",
        "2": "dwa;",
        "3": "trzy;",
        "4": "cztery;",
        "5": "pięć;",
        "6": "sześć;",
        "7": "siedem;",
        "8": "osiem;",
        "9": "dziewięć;",
        "10": "dziesięć;",
        "11": "jedenaście;",
        "12": "dwanaście;",
        "13": "trzynaście;",
        "14": "czternaście;",
        "15": "piętnaście;",
        "16": "szesnaście;",
        "17": "siedemnaście;",
        "18": "osiemnaście;",
        "19": "dziewiętnaście;",
        "(20, 99)": "<%%spellout-cardinal-tens<[ >>];",
        "(100, 199)": "sto[ >>];",
        "(200, 299)": "dwieście[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<sta[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<set[ >>];",
        "(1000, 1999)": "tysiąc[ >>];",
        "(2000, 999999)": "<< $(cardinal,few{tysiące}other{tysięcy})$[ >>];",
        "(1000000, 1999999)": "milion[ >>];",
        "(2000000, 999999999)": "<< $(cardinal,few{miliony}other{milionów})$[ >>];",
        "(1000000000, 1999999999)": "miliard[ >>];",
        "(2000000000, 999999999999)": "<< $(cardinal,few{miliardy}other{miliardów})$[ >>];",
        "(1000000000000, 1999999999999)": "bilion[ >>];",
        "(2000000000000, 999999999999999)": "<< $(cardinal,few{biliony}other{bilionów})$[ >>];",
        "(1000000000000000, 1999999999999999)": "biliard[ >>];",
        "(2000000000000000, 999999999999999999)": "<< $(cardinal,few{biliardy}other{biliardów})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-accusative": {
        "(0, 'inf')": "=%spellout-cardinal-masculine=;"
    },
    "%spellout-cardinal-masculine-accusative-animate": {
        "0": "zero;",
        "1": "jednego;",
        "(2, 'inf')": "=%spellout-cardinal-masculine=;"
    },
    "%spellout-cardinal-masculine-accusative-personal": {
        "(0, 999)": "=%spellout-cardinal-masculine-genitive=;",
        "(1000, 1999)": "tysiąc[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000, 999999)": "<%spellout-cardinal-masculine< $(cardinal,few{tysiące}other{tysięcy})$[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(1000000, 1999999)": "milion[ >>];",
        "(2000000, 999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{miliony}other{milionów})$[ >>];",
        "(1000000000, 1999999999)": "miliard[ >>];",
        "(2000000000, 999999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{miliardy}other{miliardów})$[ >>];",
        "(1000000000000, 1999999999999)": "bilion[ >>];",
        "(2000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{biliony}other{bilionów})$[ >>];",
        "(1000000000000000, 1999999999999999)": "biliard[ >>];",
        "(2000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{biliardy}other{biliardów})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-dative": {
        "0": "zeru;",
        "1": "jednemu;",
        "2": "dwóm;",
        "3": "trzem;",
        "4": "czterem;",
        "5": "pięciu;",
        "6": "sześciu;",
        "7": "siedmiu;",
        "8": "ośmiu;",
        "9": "dziewięciu;",
        "10": "dziesięciu;",
        "11": "jedenastu;",
        "12": "dwunastu;",
        "13": "trzynastu;",
        "14": "czternastu;",
        "15": "piętnastu;",
        "16": "szesnastu;",
        "17": "siedemnastu;",
        "18": "osiemnastu;",
        "19": "dziewiętnastu;",
        "(20, 99)": "<%%spellout-cardinal-genitive-tens<[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(100, 199)": "stu[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(200, 299)": "dwustu[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(300, 499)": "<%spellout-cardinal-feminine<stu[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(500, 999)": "<%spellout-cardinal-feminine-genitive<set[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(1000, 1999)": "tysiącowi[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(2000, 999999)": "<< tysiącom[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(1000000, 1999999)": "milionowi[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(2000000, 999999999)": "<< milionom[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(1000000000, 1999999999)": "miliardowi[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(2000000000, 999999999999)": "<< miliardom[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(1000000000000, 1999999999999)": "bilionowi[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(2000000000000, 999999999999999)": "<< bilionom[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(1000000000000000, 1999999999999999)": "biliardowi[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(2000000000000000, 999999999999999999)": "<< biliardom[ >%%spellout-cardinal-masculine-dative-ones>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-genitive": {
        "0": "zera;",
        "1": "jednego;",
        "2": "dwóch;",
        "3": "trzech;",
        "4": "czterech;",
        "5": "pięciu;",
        "6": "sześciu;",
        "7": "siedmiu;",
        "8": "ośmiu;",
        "9": "dziewięciu;",
        "10": "dziesięciu;",
        "11": "jedenastu;",
        "12": "dwunastu;",
        "13": "trzynastu;",
        "14": "czternastu;",
        "15": "piętnastu;",
        "16": "szesnastu;",
        "17": "siedemnastu;",
        "18": "osiemnastu;",
        "19": "dziewiętnastu;",
        "(20, 99)": "<%%spellout-cardinal-genitive-tens<[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(100, 199)": "stu[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(200, 299)": "dwustu[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(300, 499)": "<%spellout-cardinal-feminine<stu[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(500, 999)": "<%spellout-cardinal-feminine-genitive<set[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(1000, 1999)": "tysiąca[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000, 999999)": "<< tysięcy[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(1000000, 1999999)": "miliona[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000000, 999999999)": "<< milionów[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(1000000000, 1999999999)": "miliarda[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000000000, 999999999999)": "<< miliardów[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(1000000000000, 1999999999999)": "biliona[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000000000000, 999999999999999)": "<< bilionów[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(1000000000000000, 1999999999999999)": "biliarda[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000000000000000, 999999999999999999)": "<< biliardów[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-instrumental": {
        "0": "zerem;",
        "1": "jednym;",
        "2": "dwoma;",
        "3": "trzema;",
        "4": "czterema;",
        "5": "pięcioma;",
        "6": "sześcioma;",
        "7": "siedmioma;",
        "8": "ośmioma;",
        "9": "dziewięcioma;",
        "10": "dziesięcioma;",
        "11": "jedenastoma;",
        "12": "dwunastoma;",
        "13": "trzynastoma;",
        "14": "czternastoma;",
        "15": "piętnastoma;",
        "16": "szesnastoma;",
        "17": "siedemnastoma;",
        "18": "osiemnastoma;",
        "19": "dziewiętnastoma;",
        "(20, 29)": "dwudziestoma[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(30, 39)": "trzydziestoma[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(40, 49)": "czterdziestoma[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(50, 59)": "pięćdziesięcioma[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(60, 69)": "sześćdziesięcioma[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(70, 79)": "siedemdziesięcioma[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(80, 89)": "osiemdziesięcioma[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(90, 99)": "dziewięćdziesięcioma[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(100, 199)": "stu[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(200, 299)": "dwustu[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(300, 499)": "<%spellout-cardinal-feminine<stu[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(500, 999)": "<%spellout-cardinal-feminine-genitive<set[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(1000, 1999)": "tysiącem[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(2000, 999999)": "<< tysiącami[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(1000000, 1999999)": "milionem[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(2000000, 999999999)": "<< milionami[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(1000000000, 1999999999)": "miliardem[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(2000000000, 999999999999)": "<< miliardami[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(1000000000000, 1999999999999)": "bilionem[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(2000000000000, 999999999999999)": "<< bilionami[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(1000000000000000, 1999999999999999)": "biliardem[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(2000000000000000, 999999999999999999)": "<< biliardami[ >%%spellout-cardinal-masculine-instrumental-ones>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-locative": {
        "0": "zerze;",
        "1": "jednym;",
        "2": "dwóch;",
        "3": "trzech;",
        "4": "czterech;",
        "5": "pięciu;",
        "6": "sześciu;",
        "7": "siedmiu;",
        "8": "ośmiu;",
        "9": "dziewięciu;",
        "10": "dziesięciu;",
        "11": "jedenastu;",
        "12": "dwunastu;",
        "13": "trzynastu;",
        "14": "czternastu;",
        "15": "piętnastu;",
        "16": "szesnastu;",
        "17": "siedemnastu;",
        "18": "osiemnastu;",
        "19": "dziewiętnastu;",
        "(20, 99)": "<%%spellout-cardinal-genitive-tens<[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(100, 199)": "stu[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(200, 299)": "dwustu[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(300, 499)": "<%spellout-cardinal-feminine<stu[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(500, 999)": "<%spellout-cardinal-feminine-genitive<set[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(1000, 1999)": "tysiącu[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(2000, 999999)": "<< tysiącach[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(1000000, 1999999)": "milionie[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(2000000, 999999999)": "<< milionach[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(1000000000, 1999999999)": "miliardzie[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(2000000000, 999999999999)": "<< miliardach[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(1000000000000, 1999999999999)": "bilionie[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(2000000000000, 999999999999999)": "<< bilionach[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(1000000000000000, 1999999999999999)": "biliardzie[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(2000000000000000, 999999999999999999)": "<< biliardach[ >%%spellout-cardinal-masculine-locative-ones>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-personal": {
        "0": "zero;",
        "1": "jeden;",
        "2": "dwaj;",
        "3": "trzej;",
        "4": "czterej;",
        "(5, 999)": "=%spellout-cardinal-masculine-genitive=;",
        "(1000, 1999)": "tysiąc[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000, 999999)": "<%spellout-cardinal-masculine< $(cardinal,few{tysiące}other{tysięcy})$[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(1000000, 1999999)": "milion[ >>];",
        "(2000000, 999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{miliony}other{milionów})$[ >>];",
        "(1000000000, 1999999999)": "miliard[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000000000, 999999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{miliardy}other{miliardów})$[ >>];",
        "(1000000000000, 1999999999999)": "bilion[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{biliony}other{bilionów})$[ >>];",
        "(1000000000000000, 1999999999999999)": "biliard[ >%%spellout-cardinal-masculine-genitive-ones>];",
        "(2000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,few{biliardy}other{biliardów})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-neuter": {
        "0": "zero;",
        "1": "jedno;",
        "(2, 'inf')": "=%spellout-cardinal-masculine=;"
    },
    "%spellout-cardinal-neuter-accusative": {
        "0": "zero;",
        "1": "jedno;",
        "(2, 'inf')": "=%spellout-cardinal-masculine=;"
    },
    "%spellout-cardinal-neuter-dative": {
        "(0, 'inf')": "=%spellout-cardinal-masculine-dative=;"
    },
    "%spellout-cardinal-neuter-genitive": {
        "(0, 'inf')": "=%spellout-cardinal-masculine-genitive=;"
    },
    "%spellout-cardinal-neuter-instrumental": {
        "(0, 'inf')": "=%spellout-cardinal-masculine-instrumental=;"
    },
    "%spellout-cardinal-neuter-locative": {
        "(0, 'inf')": "=%spellout-cardinal-masculine-locative=;"
    },
    "%spellout-numbering": {
        "(0, 'inf')": "=%spellout-cardinal-masculine=;"
    },
    "%spellout-numbering-year": {
        "(0, 'inf')": "=%spellout-numbering=;"
    }
}