# -*- coding: utf-8 -*-
info = {
    "name": "fo",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan"
    ],
    "february": [
        "februar",
        "feb"
    ],
    "march": [
        "mars",
        "mar"
    ],
    "april": [
        "apríl",
        "apr"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "juli",
        "jul"
    ],
    "august": [
        "august",
        "aug"
    ],
    "september": [
        "september",
        "sep"
    ],
    "october": [
        "oktober",
        "okt"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "desember",
        "des"
    ],
    "monday": [
        "mánadagur",
        "mán"
    ],
    "tuesday": [
        "týsdagur",
        "týs"
    ],
    "wednesday": [
        "mikudagur",
        "mik"
    ],
    "thursday": [
        "hósdagur",
        "hós"
    ],
    "friday": [
        "fríggjadagur",
        "frí"
    ],
    "saturday": [
        "leygardagur",
        "ley"
    ],
    "sunday": [
        "sunnudagur",
        "sun"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "ár"
    ],
    "month": [
        "mánaður",
        "mnð"
    ],
    "week": [
        "vika",
        "vi",
        "v"
    ],
    "day": [
        "dagur",
        "da",
        "d"
    ],
    "hour": [
        "tími",
        "t"
    ],
    "minute": [
        "minuttur",
        "min",
        "m"
    ],
    "second": [
        "sekund",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "í fjør"
        ],
        "0 year ago": [
            "í ár"
        ],
        "in 1 year": [
            "næsta ár"
        ],
        "1 month ago": [
            "seinasta mánað"
        ],
        "0 month ago": [
            "henda mánaðin"
        ],
        "in 1 month": [
            "næsta mánað"
        ],
        "1 week ago": [
            "seinastu viku"
        ],
        "0 week ago": [
            "hesu viku"
        ],
        "in 1 week": [
            "næstu viku"
        ],
        "1 day ago": [
            "í gjár"
        ],
        "0 day ago": [
            "í dag"
        ],
        "in 1 day": [
            "í morgin"
        ],
        "0 hour ago": [
            "hendan tíman"
        ],
        "0 minute ago": [
            "hendan minuttin"
        ],
        "0 second ago": [
            "nú"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "um (\\d+) ár"
        ],
        "\\1 year ago": [
            "(\\d+) ár síðan"
        ],
        "in \\1 month": [
            "um (\\d+) mánað",
            "um (\\d+) mánaðir",
            "um (\\d+) mnð"
        ],
        "\\1 month ago": [
            "(\\d+) mánað síðan",
            "(\\d+) mánaðir síðan",
            "(\\d+) mnð síðan"
        ],
        "in \\1 week": [
            "um (\\d+) viku",
            "um (\\d+) vikur",
            "um (\\d+) vi",
            "um (\\d+) v"
        ],
        "\\1 week ago": [
            "(\\d+) vika síðan",
            "(\\d+) vikur síðan",
            "(\\d+) vi síðan",
            "(\\d+) v síðan"
        ],
        "in \\1 day": [
            "um (\\d+) dag",
            "um (\\d+) dagar",
            "um (\\d+) da",
            "um (\\d+) d"
        ],
        "\\1 day ago": [
            "(\\d+) dagur síðan",
            "(\\d+) dagar síðan",
            "(\\d+) da síðan",
            "(\\d+) d síðan"
        ],
        "in \\1 hour": [
            "um (\\d+) tíma",
            "um (\\d+) tímar",
            "um (\\d+) t"
        ],
        "\\1 hour ago": [
            "(\\d+) tími síðan",
            "(\\d+) tímar síðan",
            "(\\d+) t síðan"
        ],
        "in \\1 minute": [
            "um (\\d+) minutt",
            "um (\\d+) minuttir",
            "um (\\d+) min",
            "um (\\d+) m"
        ],
        "\\1 minute ago": [
            "(\\d+) minutt síðan",
            "(\\d+) minuttir síðan",
            "(\\d+) min síðan",
            "(\\d+) m síðan"
        ],
        "in \\1 second": [
            "um (\\d+) sekund",
            "um (\\d+) sek",
            "um (\\d+) s"
        ],
        "\\1 second ago": [
            "(\\d+) sekund síðan",
            "(\\d+) sek síðan",
            "(\\d+) s síðan"
        ]
    },
    "locale_specific": {
        "fo-DK": {
            "name": "fo-DK"
        }
    },
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}