# -*- coding: utf-8 -*-
info = {
    "name": "seh",
    "date_order": "DMY",
    "january": [
        "janeiro",
        "jan"
    ],
    "february": [
        "fevreiro",
        "fev"
    ],
    "march": [
        "marco",
        "mar"
    ],
    "april": [
        "abril",
        "abr"
    ],
    "may": [
        "maio",
        "mai"
    ],
    "june": [
        "junho",
        "jun"
    ],
    "july": [
        "julho",
        "jul"
    ],
    "august": [
        "augusto",
        "aug"
    ],
    "september": [
        "setembro",
        "set"
    ],
    "october": [
        "otubro",
        "otu"
    ],
    "november": [
        "novembro",
        "nov"
    ],
    "december": [
        "decembro",
        "dec"
    ],
    "monday": [
        "chiposi",
        "pos"
    ],
    "tuesday": [
        "chipiri",
        "pir"
    ],
    "wednesday": [
        "chitatu",
        "tat"
    ],
    "thursday": [
        "chinai",
        "nai"
    ],
    "friday": [
        "chishanu",
        "sha"
    ],
    "saturday": [
        "sabudu",
        "sab"
    ],
    "sunday": [
        "dimingu",
        "dim"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "chaka"
    ],
    "month": [
        "mwezi"
    ],
    "week": [
        "week"
    ],
    "day": [
        "ntsiku"
    ],
    "hour": [
        "hora"
    ],
    "minute": [
        "minuto"
    ],
    "second": [
        "segundo"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "zuro"
        ],
        "0 day ago": [
            "lero"
        ],
        "in 1 day": [
            "manguana"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}