# -*- coding: utf-8 -*-
info = {
    "name": "sl",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan"
    ],
    "february": [
        "februar",
        "feb"
    ],
    "march": [
        "marec",
        "mar"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "maj"
    ],
    "june": [
        "junij",
        "jun"
    ],
    "july": [
        "julij",
        "jul"
    ],
    "august": [
        "avgust",
        "avg"
    ],
    "september": [
        "september",
        "sep"
    ],
    "october": [
        "oktober",
        "okt"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "december",
        "dec"
    ],
    "monday": [
        "ponedeljek",
        "pon"
    ],
    "tuesday": [
        "torek",
        "tor"
    ],
    "wednesday": [
        "sreda",
        "sre"
    ],
    "thursday": [
        "četrtek",
        "čet"
    ],
    "friday": [
        "petek",
        "pet"
    ],
    "saturday": [
        "sobota",
        "sob"
    ],
    "sunday": [
        "nedelja",
        "ned"
    ],
    "am": [
        "dopoldne",
        "dop"
    ],
    "pm": [
        "popoldne",
        "pop"
    ],
    "year": [
        "leto"
    ],
    "month": [
        "mesec",
        "mes"
    ],
    "week": [
        "teden",
        "ted"
    ],
    "day": [
        "dan"
    ],
    "hour": [
        "ura",
        "h"
    ],
    "minute": [
        "minuta",
        "min"
    ],
    "second": [
        "sekunda",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "lani"
        ],
        "0 year ago": [
            "letos"
        ],
        "in 1 year": [
            "naslednje leto"
        ],
        "1 month ago": [
            "prejšnji mesec"
        ],
        "0 month ago": [
            "ta mesec"
        ],
        "in 1 month": [
            "naslednji mesec"
        ],
        "1 week ago": [
            "prejšnji teden"
        ],
        "0 week ago": [
            "ta teden"
        ],
        "in 1 week": [
            "naslednji teden"
        ],
        "1 day ago": [
            "včeraj"
        ],
        "0 day ago": [
            "danes"
        ],
        "in 1 day": [
            "jutri"
        ],
        "0 hour ago": [
            "v tej uri"
        ],
        "0 minute ago": [
            "to minuto"
        ],
        "0 second ago": [
            "zdaj"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "čez (\\d+) leto",
            "čez (\\d+) let"
        ],
        "\\1 year ago": [
            "pred (\\d+) letom",
            "pred (\\d+) leti"
        ],
        "in \\1 month": [
            "čez (\\d+) mesec",
            "čez (\\d+) mesecev",
            "čez (\\d+) mes"
        ],
        "\\1 month ago": [
            "pred (\\d+) mesecem",
            "pred (\\d+) meseci",
            "pred (\\d+) mes"
        ],
        "in \\1 week": [
            "čez (\\d+) teden",
            "čez (\\d+) tednov",
            "čez (\\d+) ted"
        ],
        "\\1 week ago": [
            "pred (\\d+) tednom",
            "pred (\\d+) tedni",
            "pred (\\d+) ted"
        ],
        "in \\1 day": [
            "čez (\\d+) dan",
            "čez (\\d+) dni"
        ],
        "\\1 day ago": [
            "pred (\\d+) dnevom",
            "pred (\\d+) dnevi"
        ],
        "in \\1 hour": [
            "čez (\\d+) uro",
            "čez (\\d+) ur",
            "čez (\\d+) h"
        ],
        "\\1 hour ago": [
            "pred (\\d+) uro",
            "pred (\\d+) urami",
            "pred (\\d+) h"
        ],
        "in \\1 minute": [
            "čez (\\d+) minuto",
            "čez (\\d+) minut",
            "čez (\\d+) min"
        ],
        "\\1 minute ago": [
            "pred (\\d+) minuto",
            "pred (\\d+) minutami",
            "pred (\\d+) min"
        ],
        "in \\1 second": [
            "čez (\\d+) sekundo",
            "čez (\\d+) sekund",
            "čez (\\d+) s"
        ],
        "\\1 second ago": [
            "pred (\\d+) sekundo",
            "pred (\\d+) sekundami",
            "pred (\\d+) s"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}