# -*- coding: utf-8 -*-
info = {
    "name": "ro",
    "date_order": "DMY",
    "january": [
        "ianuarie",
        "ian"
    ],
    "february": [
        "februarie",
        "feb",
        "Febr"
    ],
    "march": [
        "martie",
        "mar",
        "Mart"
    ],
    "april": [
        "aprilie",
        "apr"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "iunie",
        "iun"
    ],
    "july": [
        "iulie",
        "iul"
    ],
    "august": [
        "august",
        "aug"
    ],
    "september": [
        "septembrie",
        "sept",
        "Sep"
    ],
    "october": [
        "octombrie",
        "oct"
    ],
    "november": [
        "noiembrie",
        "nov",
        "Noiem"
    ],
    "december": [
        "decembrie",
        "dec"
    ],
    "monday": [
        "luni",
        "lun"
    ],
    "tuesday": [
        "marți",
        "mar"
    ],
    "wednesday": [
        "miercuri",
        "mie",
        "Mi"
    ],
    "thursday": [
        "joi"
    ],
    "friday": [
        "vineri",
        "vin"
    ],
    "saturday": [
        "sâmbătă",
        "sâm"
    ],
    "sunday": [
        "duminică",
        "dum"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "an",
        "ani"
    ],
    "month": [
        "lună",
        "luna",
        "luni"
    ],
    "week": [
        "săptămână",
        "săpt",
        "săptămâni"
    ],
    "day": [
        "zi",
        "zile"
    ],
    "hour": [
        "oră",
        "h",
        "ore"
    ],
    "minute": [
        "minut",
        "min",
        "m",
        "minute"
    ],
    "second": [
        "secundă",
        "sec",
        "s",
        "secunde"
    ],
    "relative-type": {
        "1 year ago": [
            "anul trecut"
        ],
        "0 year ago": [
            "anul acesta"
        ],
        "in 1 year": [
            "anul viitor"
        ],
        "1 month ago": [
            "luna trecută"
        ],
        "0 month ago": [
            "luna aceasta"
        ],
        "in 1 month": [
            "luna viitoare"
        ],
        "1 week ago": [
            "săptămâna trecută"
        ],
        "0 week ago": [
            "săptămâna aceasta"
        ],
        "in 1 week": [
            "săptămâna viitoare"
        ],
        "1 day ago": [
            "ieri"
        ],
        "0 day ago": [
            "azi"
        ],
        "in 1 day": [
            "mâine"
        ],
        "0 hour ago": [
            "ora aceasta"
        ],
        "0 minute ago": [
            "minutul acesta"
        ],
        "0 second ago": [
            "acum"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "peste (\\d+) an",
            "peste (\\d+) de ani",
            "peste (\\d+) ani"
        ],
        "\\1 year ago": [
            "acum (\\d+) an",
            "acum (\\d+) de ani"
        ],
        "in \\1 month": [
            "peste (\\d+) lună",
            "peste (\\d+) de luni",
            "peste (\\d+) luni"
        ],
        "\\1 month ago": [
            "acum (\\d+) lună",
            "acum (\\d+) de luni",
            "acum (\\d+) luni"
        ],
        "in \\1 week": [
            "peste (\\d+) săptămână",
            "peste (\\d+) de săptămâni",
            "peste (\\d+) săpt"
        ],
        "\\1 week ago": [
            "acum (\\d+) săptămână",
            "acum (\\d+) de săptămâni",
            "acum (\\d+) săpt"
        ],
        "in \\1 day": [
            "peste (\\d+) zi",
            "peste (\\d+) de zile",
            "peste (\\d+) zile"
        ],
        "\\1 day ago": [
            "acum (\\d+) zi",
            "acum (\\d+) de zile",
            "acum (\\d+) zile"
        ],
        "in \\1 hour": [
            "peste (\\d+) oră",
            "peste (\\d+) de ore",
            "peste (\\d+) h"
        ],
        "\\1 hour ago": [
            "acum (\\d+) oră",
            "acum (\\d+) de ore",
            "acum (\\d+) h"
        ],
        "in \\1 minute": [
            "peste (\\d+) minut",
            "peste (\\d+) de minute",
            "peste (\\d+) min"
        ],
        "\\1 minute ago": [
            "acum (\\d+) minut",
            "acum (\\d+) de minute",
            "acum (\\d+) min"
        ],
        "in \\1 second": [
            "peste (\\d+) secundă",
            "peste (\\d+) de secunde",
            "peste (\\d+) sec"
        ],
        "\\1 second ago": [
            "acum (\\d+) secundă",
            "acum (\\d+) de secunde",
            "acum (\\d+) sec"
        ]
    },
    "locale_specific": {
        "ro-MD": {
            "name": "ro-MD"
        }
    },
    "skip": [
        "la",
        "de",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "în urmă"
    ],
    "in": [
        "în"
    ]
}