# -*- coding: utf-8 -*-
info = {
    "name": "ksb",
    "date_order": "DMY",
    "january": [
        "januali",
        "jan"
    ],
    "february": [
        "febluali",
        "feb"
    ],
    "march": [
        "machi",
        "mac"
    ],
    "april": [
        "aplili",
        "apr"
    ],
    "may": [
        "mei"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "julai",
        "jul"
    ],
    "august": [
        "agosti",
        "ago"
    ],
    "september": [
        "septemba",
        "sep"
    ],
    "october": [
        "oktoba",
        "okt"
    ],
    "november": [
        "novemba",
        "nov"
    ],
    "december": [
        "desemba",
        "des"
    ],
    "monday": [
        "jumaatatu",
        "jtt"
    ],
    "tuesday": [
        "jumaane",
        "jmn"
    ],
    "wednesday": [
        "jumaatano",
        "jtn"
    ],
    "thursday": [
        "alhamisi",
        "alh"
    ],
    "friday": [
        "ijumaa",
        "iju"
    ],
    "saturday": [
        "jumaamosi",
        "jmo"
    ],
    "sunday": [
        "jumaapii",
        "jpi"
    ],
    "am": [
        "makeo"
    ],
    "pm": [
        "nyiaghuo"
    ],
    "year": [
        "ng'waka"
    ],
    "month": [
        "ng'ezi"
    ],
    "week": [
        "niki"
    ],
    "day": [
        "siku"
    ],
    "hour": [
        "saa"
    ],
    "minute": [
        "dakika"
    ],
    "second": [
        "sekunde"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "ghuo"
        ],
        "0 day ago": [
            "evi eo"
        ],
        "in 1 day": [
            "keloi"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}