# -*- coding: utf-8 -*-
info = {
    "name": "mg",
    "date_order": "YMD",
    "january": [
        "janoary",
        "jan"
    ],
    "february": [
        "febroary",
        "feb"
    ],
    "march": [
        "martsa",
        "mar"
    ],
    "april": [
        "aprily",
        "apr"
    ],
    "may": [
        "mey"
    ],
    "june": [
        "jona",
        "jon"
    ],
    "july": [
        "jolay",
        "jol"
    ],
    "august": [
        "aogositra",
        "aog"
    ],
    "september": [
        "septambra",
        "sep"
    ],
    "october": [
        "oktobra",
        "okt"
    ],
    "november": [
        "novambra",
        "nov"
    ],
    "december": [
        "desambra",
        "des"
    ],
    "monday": [
        "alatsinainy",
        "alats"
    ],
    "tuesday": [
        "talata",
        "tal"
    ],
    "wednesday": [
        "alarobia",
        "alar"
    ],
    "thursday": [
        "alakamisy",
        "alak"
    ],
    "friday": [
        "zoma",
        "zom"
    ],
    "saturday": [
        "asabotsy",
        "asab"
    ],
    "sunday": [
        "alahady",
        "alah"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "taona"
    ],
    "month": [
        "volana"
    ],
    "week": [
        "herinandro"
    ],
    "day": [
        "andro"
    ],
    "hour": [
        "ora"
    ],
    "minute": [
        "minitra"
    ],
    "second": [
        "segondra"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "omaly"
        ],
        "0 day ago": [
            "anio"
        ],
        "in 1 day": [
            "rahampitso"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}