# -*- coding: utf-8 -*-
info = {
    "name": "ff",
    "date_order": "DMY",
    "january": [
        "siilo",
        "sii"
    ],
    "february": [
        "colte",
        "col"
    ],
    "march": [
        "mbooy",
        "mbo"
    ],
    "april": [
        "seeɗto",
        "see"
    ],
    "may": [
        "duujal",
        "duu"
    ],
    "june": [
        "korse",
        "kor"
    ],
    "july": [
        "morso",
        "mor"
    ],
    "august": [
        "juko",
        "juk"
    ],
    "september": [
        "siilto",
        "slt"
    ],
    "october": [
        "yarkomaa",
        "yar"
    ],
    "november": [
        "jolal",
        "jol"
    ],
    "december": [
        "bowte",
        "bow"
    ],
    "monday": [
        "aaɓnde",
        "aaɓ"
    ],
    "tuesday": [
        "mawbaare",
        "maw"
    ],
    "wednesday": [
        "njeslaare",
        "nje"
    ],
    "thursday": [
        "naasaande",
        "naa"
    ],
    "friday": [
        "mawnde",
        "mwd"
    ],
    "saturday": [
        "hoore-biir",
        "hbi"
    ],
    "sunday": [
        "dewo",
        "dew"
    ],
    "am": [
        "subaka"
    ],
    "pm": [
        "kikiiɗe"
    ],
    "year": [
        "hitaande"
    ],
    "month": [
        "lewru"
    ],
    "week": [
        "yontere"
    ],
    "day": [
        "ñalnde"
    ],
    "hour": [
        "waktu"
    ],
    "minute": [
        "hoƴom"
    ],
    "second": [
        "majaango"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "haŋki"
        ],
        "0 day ago": [
            "hannde"
        ],
        "in 1 day": [
            "jaŋngo"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {
        "ff-GN": {
            "name": "ff-GN"
        },
        "ff-MR": {
            "name": "ff-MR"
        },
        "ff-CM": {
            "name": "ff-CM"
        }
    },
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}