# -*- coding: utf-8 -*-
info = {
    "name": "br",
    "date_order": "YMD",
    "january": [
        "genver",
        "gen"
    ],
    "february": [
        "c'hwevrer",
        "c'hwe"
    ],
    "march": [
        "meurzh",
        "meur"
    ],
    "april": [
        "ebrel",
        "ebr"
    ],
    "may": [
        "mae"
    ],
    "june": [
        "mezheven",
        "mezh"
    ],
    "july": [
        "gouere",
        "goue"
    ],
    "august": [
        "eost"
    ],
    "september": [
        "gwengolo",
        "gwen"
    ],
    "october": [
        "here"
    ],
    "november": [
        "du"
    ],
    "december": [
        "kerzu",
        "ker",
        "kzu"
    ],
    "monday": [
        "lun"
    ],
    "tuesday": [
        "meurzh",
        "meu"
    ],
    "wednesday": [
        "merc'her",
        "mer"
    ],
    "thursday": [
        "yaou"
    ],
    "friday": [
        "gwener",
        "gwe"
    ],
    "saturday": [
        "sadorn",
        "sad"
    ],
    "sunday": [
        "sul"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "gm"
    ],
    "year": [
        "bloaz",
        "bl"
    ],
    "month": [
        "miz"
    ],
    "week": [
        "sizhun"
    ],
    "day": [
        "deiz",
        "d"
    ],
    "hour": [
        "eur",
        "e"
    ],
    "minute": [
        "munut",
        "min"
    ],
    "second": [
        "eilenn",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "warlene"
        ],
        "0 year ago": [
            "hevlene"
        ],
        "in 1 year": [
            "ar bloaz a zeu",
            "ar bl a zeu"
        ],
        "1 month ago": [
            "ar miz diaraok"
        ],
        "0 month ago": [
            "ar miz-mañ"
        ],
        "in 1 month": [
            "ar miz a zeu"
        ],
        "1 week ago": [
            "ar sizhun diaraok"
        ],
        "0 week ago": [
            "ar sizhun-mañ"
        ],
        "in 1 week": [
            "ar sizhun a zeu"
        ],
        "1 day ago": [
            "dec'h"
        ],
        "0 day ago": [
            "hiziv"
        ],
        "in 1 day": [
            "warc'hoazh"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "bremañ",
            "brem"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "a-benn (\\d+) bloaz",
            "a-benn (\\d+) vloaz",
            "a-benn (\\d+) bl"
        ],
        "\\1 year ago": [
            "(\\d+) bloaz zo",
            "(\\d+) vloaz zo",
            "(\\d+) bl zo"
        ],
        "in \\1 month": [
            "a-benn (\\d+) miz"
        ],
        "\\1 month ago": [
            "(\\d+) miz zo"
        ],
        "in \\1 week": [
            "a-benn (\\d+) sizhun"
        ],
        "\\1 week ago": [
            "(\\d+) sizhun zo"
        ],
        "in \\1 day": [
            "a-benn (\\d+) deiz",
            "a-benn (\\d+) d"
        ],
        "\\1 day ago": [
            "(\\d+) deiz zo",
            "(\\d+) d zo"
        ],
        "in \\1 hour": [
            "a-benn (\\d+) eur",
            "a-benn (\\d+) e"
        ],
        "\\1 hour ago": [
            "(\\d+) eur zo",
            "(\\d+) e zo"
        ],
        "in \\1 minute": [
            "a-benn (\\d+) munut",
            "a-benn (\\d+) min"
        ],
        "\\1 minute ago": [
            "(\\d+) munut zo",
            "(\\d+) min zo"
        ],
        "in \\1 second": [
            "a-benn (\\d+) eilenn",
            "a-benn (\\d+) s"
        ],
        "\\1 second ago": [
            "(\\d+) eilenn zo",
            "(\\d+) s zo"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}