# -*- coding: utf-8 -*-
info = {
    "name": "fy",
    "date_order": "DMY",
    "january": [
        "jannewaris",
        "jan"
    ],
    "february": [
        "febrewaris",
        "feb"
    ],
    "march": [
        "maart",
        "mrt"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "maaie",
        "mai"
    ],
    "june": [
        "juny",
        "jun"
    ],
    "july": [
        "july",
        "jul"
    ],
    "august": [
        "augustus",
        "aug"
    ],
    "september": [
        "septimber",
        "sep"
    ],
    "october": [
        "oktober",
        "okt"
    ],
    "november": [
        "novimber",
        "nov"
    ],
    "december": [
        "desimber",
        "des"
    ],
    "monday": [
        "moandei",
        "mo"
    ],
    "tuesday": [
        "tiisdei",
        "ti"
    ],
    "wednesday": [
        "woansdei",
        "wo"
    ],
    "thursday": [
        "tongersdei",
        "to"
    ],
    "friday": [
        "freed",
        "fr"
    ],
    "saturday": [
        "sneon",
        "so"
    ],
    "sunday": [
        "snein",
        "si"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "jier"
    ],
    "month": [
        "moanne"
    ],
    "week": [
        "wike"
    ],
    "day": [
        "dei"
    ],
    "hour": [
        "oere"
    ],
    "minute": [
        "minút"
    ],
    "second": [
        "sekonde"
    ],
    "relative-type": {
        "1 year ago": [
            "foarich jier"
        ],
        "0 year ago": [
            "dit jier"
        ],
        "in 1 year": [
            "folgjend jier"
        ],
        "1 month ago": [
            "foarige moanne"
        ],
        "0 month ago": [
            "dizze moanne"
        ],
        "in 1 month": [
            "folgjende moanne"
        ],
        "1 week ago": [
            "foarige wike"
        ],
        "0 week ago": [
            "dizze wike"
        ],
        "in 1 week": [
            "folgjende wike"
        ],
        "1 day ago": [
            "gisteren"
        ],
        "0 day ago": [
            "vandaag"
        ],
        "in 1 day": [
            "morgen"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "nu"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "oer (\\d+) jier"
        ],
        "\\1 year ago": [
            "(\\d+) jier lyn"
        ],
        "in \\1 month": [
            "oer (\\d+) moanne",
            "oer (\\d+) moannen"
        ],
        "\\1 month ago": [
            "(\\d+) moanne lyn",
            "(\\d+) moannen lyn"
        ],
        "in \\1 week": [
            "oer (\\d+) wike",
            "oer (\\d+) wiken"
        ],
        "\\1 week ago": [
            "(\\d+) wike lyn",
            "(\\d+) wiken lyn"
        ],
        "in \\1 day": [
            "oer (\\d+) dei",
            "oer (\\d+) deien"
        ],
        "\\1 day ago": [
            "(\\d+) dei lyn",
            "(\\d+) deien lyn"
        ],
        "in \\1 hour": [
            "oer (\\d+) oere"
        ],
        "\\1 hour ago": [
            "(\\d+) oere lyn"
        ],
        "in \\1 minute": [
            "oer (\\d+) minút",
            "oer (\\d+) minuten"
        ],
        "\\1 minute ago": [
            "(\\d+) minút lyn",
            "(\\d+) minuten lyn"
        ],
        "in \\1 second": [
            "oer (\\d+) sekonde",
            "oer (\\d+) sekonden"
        ],
        "\\1 second ago": [
            "(\\d+) sekonde lyn",
            "(\\d+) sekonden lyn"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}