# -*- coding: utf-8 -*-
info = {
    "name": "bem",
    "date_order": "DMY",
    "january": [
        "januari",
        "jan"
    ],
    "february": [
        "februari",
        "feb"
    ],
    "march": [
        "machi",
        "mac"
    ],
    "april": [
        "epreo",
        "epr"
    ],
    "may": [
        "mei"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "julai",
        "jul"
    ],
    "august": [
        "ogasti",
        "oga"
    ],
    "september": [
        "septemba",
        "sep"
    ],
    "october": [
        "oktoba",
        "okt"
    ],
    "november": [
        "novemba",
        "nov"
    ],
    "december": [
        "disemba",
        "dis"
    ],
    "monday": [
        "palichimo"
    ],
    "tuesday": [
        "palichibuli"
    ],
    "wednesday": [
        "palichitatu"
    ],
    "thursday": [
        "palichine"
    ],
    "friday": [
        "palichisano"
    ],
    "saturday": [
        "pachibelushi"
    ],
    "sunday": [
        "pa mulungu"
    ],
    "am": [
        "uluchelo"
    ],
    "pm": [
        "akasuba"
    ],
    "year": [
        "umwaka"
    ],
    "month": [
        "umweshi"
    ],
    "week": [
        "umulungu"
    ],
    "day": [
        "ubushiku"
    ],
    "hour": [
        "insa"
    ],
    "minute": [
        "mineti"
    ],
    "second": [
        "sekondi"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "0 day ago": [
            "lelo"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}