# -*- coding: utf-8 -*-
info = {
    "name": "uz-Arab",
    "date_order": "YMD",
    "january": [
        "جنوری",
        "جنو"
    ],
    "february": [
        "فبروری",
        "فبر"
    ],
    "march": [
        "مارچ",
        "مار"
    ],
    "april": [
        "اپریل",
        "اپر"
    ],
    "may": [
        "می"
    ],
    "june": [
        "جون"
    ],
    "july": [
        "جولای",
        "جول"
    ],
    "august": [
        "اگست",
        "اگس"
    ],
    "september": [
        "سپتمبر",
        "سپت"
    ],
    "october": [
        "اکتوبر",
        "اکت"
    ],
    "november": [
        "نومبر",
        "نوم"
    ],
    "december": [
        "دسمبر",
        "دسم"
    ],
    "monday": [
        "دوشنبه",
        "د"
    ],
    "tuesday": [
        "سه‌شنبه",
        "س"
    ],
    "wednesday": [
        "چهارشنبه",
        "چ"
    ],
    "thursday": [
        "پنجشنبه",
        "پ"
    ],
    "friday": [
        "جمعه",
        "ج"
    ],
    "saturday": [
        "شنبه",
        "ش"
    ],
    "sunday": [
        "یکشنبه",
        "ی"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "year"
    ],
    "month": [
        "month"
    ],
    "week": [
        "week"
    ],
    "day": [
        "day"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "0 day ago": [
            "today"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}