# -*- coding: utf-8 -*-
info = {
    "name": "am",
    "date_order": "DMY",
    "january": [
        "ጃንዩወሪ",
        "ጃንዩ"
    ],
    "february": [
        "ፌብሩወሪ",
        "ፌብሩ"
    ],
    "march": [
        "ማርች"
    ],
    "april": [
        "ኤፕሪል",
        "ኤፕሪ"
    ],
    "may": [
        "ሜይ"
    ],
    "june": [
        "ጁን"
    ],
    "july": [
        "ጁላይ"
    ],
    "august": [
        "ኦገስት",
        "ኦገስ"
    ],
    "september": [
        "ሴፕቴምበር",
        "ሴፕቴ"
    ],
    "october": [
        "ኦክቶበር",
        "ኦክቶ"
    ],
    "november": [
        "ኖቬምበር",
        "ኖቬም"
    ],
    "december": [
        "ዲሴምበር",
        "ዲሴም"
    ],
    "monday": [
        "ሰኞ"
    ],
    "tuesday": [
        "ማክሰኞ",
        "ማክሰ"
    ],
    "wednesday": [
        "ረቡዕ"
    ],
    "thursday": [
        "ሐሙስ"
    ],
    "friday": [
        "ዓርብ"
    ],
    "saturday": [
        "ቅዳሜ"
    ],
    "sunday": [
        "እሑድ"
    ],
    "am": [
        "ጥዋት"
    ],
    "pm": [
        "ከሰዓት"
    ],
    "year": [
        "ዓመት"
    ],
    "month": [
        "ወር"
    ],
    "week": [
        "ሳምንት"
    ],
    "day": [
        "ቀን"
    ],
    "hour": [
        "ሰዓት"
    ],
    "minute": [
        "ደቂቃ"
    ],
    "second": [
        "ሰከንድ"
    ],
    "relative-type": {
        "1 year ago": [
            "ያለፈው ዓመት"
        ],
        "0 year ago": [
            "በዚህ ዓመት"
        ],
        "in 1 year": [
            "የሚቀጥለው ዓመት"
        ],
        "1 month ago": [
            "ያለፈው ወር"
        ],
        "0 month ago": [
            "በዚህ ወር"
        ],
        "in 1 month": [
            "የሚቀጥለው ወር"
        ],
        "1 week ago": [
            "ያለፈው ሳምንት",
            "ባለፈው ሳምንት"
        ],
        "0 week ago": [
            "በዚህ ሳምንት",
            "በዚህ ሣምንት"
        ],
        "in 1 week": [
            "የሚቀጥለው ሳምንት"
        ],
        "1 day ago": [
            "ትናንት",
            "ትላንትና"
        ],
        "0 day ago": [
            "ዛሬ"
        ],
        "in 1 day": [
            "ነገ"
        ],
        "0 hour ago": [
            "ይህ ሰዓት"
        ],
        "0 minute ago": [
            "ይህ ደቂቃ"
        ],
        "0 second ago": [
            "አሁን"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "በ(\\d+) ዓመታት ውስጥ"
        ],
        "\\1 year ago": [
            "ከ(\\d+) ዓመት በፊት",
            "ከ(\\d+) ዓመታት በፊት"
        ],
        "in \\1 month": [
            "በ(\\d+) ወር ውስጥ",
            "በ(\\d+) ወራት ውስጥ"
        ],
        "\\1 month ago": [
            "ከ(\\d+) ወር በፊት",
            "ከ(\\d+) ወራት በፊት"
        ],
        "in \\1 week": [
            "በ(\\d+) ሳምንት ውስጥ",
            "በ(\\d+) ሳምንታት ውስጥ"
        ],
        "\\1 week ago": [
            "ከ(\\d+) ሳምንት በፊት",
            "ከ(\\d+) ሳምንታት በፊት"
        ],
        "in \\1 day": [
            "በ(\\d+) ቀን ውስጥ",
            "በ(\\d+) ቀናት ውስጥ",
            "በ(\\d+) ቀኖች ውስጥ"
        ],
        "\\1 day ago": [
            "ከ(\\d+) ቀን በፊት",
            "ከ(\\d+) ቀናት በፊት",
            "ከ (\\d+) ቀን በፊት",
            "ከ(\\d+) ቀኖች በፊት"
        ],
        "in \\1 hour": [
            "በ(\\d+) ሰዓት ውስጥ",
            "በ(\\d+) ሰዓቶች ውስጥ"
        ],
        "\\1 hour ago": [
            "ከ(\\d+) ሰዓት በፊት",
            "ከ(\\d+) ሰዓቶች በፊት"
        ],
        "in \\1 minute": [
            "በ(\\d+) ደቂቃ ውስጥ",
            "በ(\\d+) ደቂቃዎች ውስጥ"
        ],
        "\\1 minute ago": [
            "ከ(\\d+) ደቂቃ በፊት",
            "ከ(\\d+) ደቂቃዎች በፊት"
        ],
        "in \\1 second": [
            "በ(\\d+) ሰከንድ ውስጥ",
            "በ(\\d+) ሰከንዶች ውስጥ"
        ],
        "\\1 second ago": [
            "ከ(\\d+) ሰከንድ በፊት",
            "ከ(\\d+) ሰከንዶች በፊት"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}