# -*- coding: utf-8 -*-
info = {
    "name": "kln",
    "date_order": "DMY",
    "january": [
        "mulgul",
        "mul"
    ],
    "february": [
        "ng'atyaato",
        "ngat"
    ],
    "march": [
        "kiptaamo",
        "taa"
    ],
    "april": [
        "iwootkuut",
        "iwo"
    ],
    "may": [
        "mamuut",
        "mam"
    ],
    "june": [
        "paagi",
        "paa"
    ],
    "july": [
        "ng'eiyeet",
        "nge"
    ],
    "august": [
        "rooptui",
        "roo"
    ],
    "september": [
        "bureet",
        "bur"
    ],
    "october": [
        "epeeso",
        "epe"
    ],
    "november": [
        "kipsuunde ne taai",
        "kpt"
    ],
    "december": [
        "kipsuunde nebo aeng'",
        "kpa"
    ],
    "monday": [
        "kotaai",
        "kot"
    ],
    "tuesday": [
        "koaeng'",
        "koo"
    ],
    "wednesday": [
        "kosomok",
        "kos"
    ],
    "thursday": [
        "koang'wan",
        "koa"
    ],
    "friday": [
        "komuut",
        "kom"
    ],
    "saturday": [
        "kolo",
        "kol"
    ],
    "sunday": [
        "kotisap",
        "kts"
    ],
    "am": [
        "krn",
        "karoon"
    ],
    "pm": [
        "koosk",
        "kooskoliny"
    ],
    "year": [
        "kenyit"
    ],
    "month": [
        "arawet"
    ],
    "week": [
        "wikit"
    ],
    "day": [
        "betut"
    ],
    "hour": [
        "sait"
    ],
    "minute": [
        "minitit"
    ],
    "second": [
        "sekondit"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "amut"
        ],
        "0 day ago": [
            "raini"
        ],
        "in 1 day": [
            "mutai"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}