# -*- coding: utf-8 -*-
info = {
    "name": "zgh",
    "date_order": "DMY",
    "january": [
        "ⵉⵏⵏⴰⵢⵔ",
        "ⵉⵏⵏ"
    ],
    "february": [
        "ⴱⵕⴰⵢⵕ",
        "ⴱⵕⴰ"
    ],
    "march": [
        "ⵎⴰⵕⵚ",
        "ⵎⴰⵕ"
    ],
    "april": [
        "ⵉⴱⵔⵉⵔ",
        "ⵉⴱⵔ"
    ],
    "may": [
        "ⵎⴰⵢⵢⵓ",
        "ⵎⴰⵢ"
    ],
    "june": [
        "ⵢⵓⵏⵢⵓ",
        "ⵢⵓⵏ"
    ],
    "july": [
        "ⵢⵓⵍⵢⵓⵣ",
        "ⵢⵓⵍ"
    ],
    "august": [
        "ⵖⵓⵛⵜ",
        "ⵖⵓⵛ"
    ],
    "september": [
        "ⵛⵓⵜⴰⵏⴱⵉⵔ",
        "ⵛⵓⵜ"
    ],
    "october": [
        "ⴽⵜⵓⴱⵔ",
        "ⴽⵜⵓ"
    ],
    "november": [
        "ⵏⵓⵡⴰⵏⴱⵉⵔ",
        "ⵏⵓⵡ"
    ],
    "december": [
        "ⴷⵓⵊⴰⵏⴱⵉⵔ",
        "ⴷⵓⵊ"
    ],
    "monday": [
        "ⴰⵢⵏⴰⵙ",
        "ⴰⵢⵏ"
    ],
    "tuesday": [
        "ⴰⵙⵉⵏⴰⵙ",
        "ⴰⵙⵉ"
    ],
    "wednesday": [
        "ⴰⴽⵕⴰⵙ",
        "ⴰⴽⵕ"
    ],
    "thursday": [
        "ⴰⴽⵡⴰⵙ",
        "ⴰⴽⵡ"
    ],
    "friday": [
        "ⴰⵙⵉⵎⵡⴰⵙ",
        "ⴰⵙⵉⵎ"
    ],
    "saturday": [
        "ⴰⵙⵉⴹⵢⴰⵙ",
        "ⴰⵙⵉⴹ"
    ],
    "sunday": [
        "ⴰⵙⴰⵎⴰⵙ",
        "ⴰⵙⴰ"
    ],
    "am": [
        "ⵜⵉⴼⴰⵡⵜ"
    ],
    "pm": [
        "ⵜⴰⴷⴳⴳⵯⴰⵜ"
    ],
    "year": [
        "ⴰⵙⴳⴳⵯⴰⵙ"
    ],
    "month": [
        "ⴰⵢⵢⵓⵔ"
    ],
    "week": [
        "ⵉⵎⴰⵍⴰⵙⵙ"
    ],
    "day": [
        "ⴰⵙⵙ"
    ],
    "hour": [
        "ⵜⴰⵙⵔⴰⴳⵜ"
    ],
    "minute": [
        "ⵜⵓⵙⴷⵉⴷⵜ"
    ],
    "second": [
        "ⵜⴰⵙⵉⵏⵜ"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "ⵉⴹⵍⵍⵉ"
        ],
        "0 day ago": [
            "ⴰⵙⵙⴰ"
        ],
        "in 1 day": [
            "ⴰⵙⴽⴽⴰ"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}