# -*- coding: utf-8 -*-
info = {
    "name": "ha",
    "date_order": "DMY",
    "january": [
        "janairu",
        "jan"
    ],
    "february": [
        "faburairu",
        "fab"
    ],
    "march": [
        "maris",
        "mar"
    ],
    "april": [
        "afirilu",
        "afi"
    ],
    "may": [
        "mayu",
        "may"
    ],
    "june": [
        "yuni",
        "yun"
    ],
    "july": [
        "yuli",
        "yul"
    ],
    "august": [
        "agusta",
        "agu"
    ],
    "september": [
        "satumba",
        "sat"
    ],
    "october": [
        "oktoba",
        "okt"
    ],
    "november": [
        "nuwamba",
        "nuw"
    ],
    "december": [
        "disamba",
        "dis"
    ],
    "monday": [
        "litinin",
        "lit"
    ],
    "tuesday": [
        "talata",
        "tal"
    ],
    "wednesday": [
        "laraba",
        "lar"
    ],
    "thursday": [
        "alhamis",
        "alh"
    ],
    "friday": [
        "jumma'a",
        "jum"
    ],
    "saturday": [
        "asabar",
        "asa"
    ],
    "sunday": [
        "lahadi",
        "lah"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "shekara"
    ],
    "month": [
        "wata"
    ],
    "week": [
        "mako"
    ],
    "day": [
        "kwana"
    ],
    "hour": [
        "awa"
    ],
    "minute": [
        "minti"
    ],
    "second": [
        "daƙiƙa"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "jiya"
        ],
        "0 day ago": [
            "yau"
        ],
        "in 1 day": [
            "gobe"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {
        "ha-GH": {
            "name": "ha-GH"
        },
        "ha-NE": {
            "name": "ha-NE"
        }
    },
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}