# -*- coding: utf-8 -*-
info = {
    "name": "sn",
    "date_order": "YMD",
    "january": [
        "ndira",
        "ndi"
    ],
    "february": [
        "kukadzi",
        "kuk"
    ],
    "march": [
        "kurume",
        "kur"
    ],
    "april": [
        "kubvumbi",
        "kub"
    ],
    "may": [
        "chivabvu",
        "chv"
    ],
    "june": [
        "chikumi",
        "chk"
    ],
    "july": [
        "chikunguru",
        "chg"
    ],
    "august": [
        "nyamavhuvhu",
        "nya"
    ],
    "september": [
        "gunyana",
        "gun"
    ],
    "october": [
        "gumiguru",
        "gum"
    ],
    "november": [
        "mbudzi",
        "mbu"
    ],
    "december": [
        "zvita",
        "zvi"
    ],
    "monday": [
        "muvhuro",
        "muv"
    ],
    "tuesday": [
        "chipiri",
        "chp"
    ],
    "wednesday": [
        "chitatu",
        "cht"
    ],
    "thursday": [
        "china",
        "chn"
    ],
    "friday": [
        "chishanu",
        "chs"
    ],
    "saturday": [
        "mugovera",
        "mug"
    ],
    "sunday": [
        "svondo",
        "svo"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "gore"
    ],
    "month": [
        "mwedzi"
    ],
    "week": [
        "vhiki"
    ],
    "day": [
        "zuva"
    ],
    "hour": [
        "awa"
    ],
    "minute": [
        "mineti"
    ],
    "second": [
        "sekondi"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "nezuro"
        ],
        "0 day ago": [
            "nhasi"
        ],
        "in 1 day": [
            "mangwana"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}