# -*- coding: utf-8 -*-
info = {
    "name": "bez",
    "date_order": "DMY",
    "january": [
        "pa mwedzi gwa hutala",
        "hut"
    ],
    "february": [
        "pa mwedzi gwa wuvili",
        "vil"
    ],
    "march": [
        "pa mwedzi gwa wudatu",
        "dat"
    ],
    "april": [
        "pa mwedzi gwa wutai",
        "tai"
    ],
    "may": [
        "pa mwedzi gwa wuhanu",
        "han"
    ],
    "june": [
        "pa mwedzi gwa sita",
        "sit"
    ],
    "july": [
        "pa mwedzi gwa saba",
        "sab"
    ],
    "august": [
        "pa mwedzi gwa nane",
        "nan"
    ],
    "september": [
        "pa mwedzi gwa tisa",
        "tis"
    ],
    "october": [
        "pa mwedzi gwa kumi",
        "kum"
    ],
    "november": [
        "pa mwedzi gwa kumi na moja",
        "kmj"
    ],
    "december": [
        "pa mwedzi gwa kumi na mbili",
        "kmb"
    ],
    "monday": [
        "pa shahuviluha",
        "vil"
    ],
    "tuesday": [
        "pa hivili",
        "hiv"
    ],
    "wednesday": [
        "pa hidatu",
        "hid"
    ],
    "thursday": [
        "pa hitayi",
        "hit"
    ],
    "friday": [
        "pa hihanu",
        "hih"
    ],
    "saturday": [
        "pa shahulembela",
        "lem"
    ],
    "sunday": [
        "pa mulungu",
        "mul"
    ],
    "am": [
        "pamilau"
    ],
    "pm": [
        "pamunyi"
    ],
    "year": [
        "mwaha"
    ],
    "month": [
        "mwedzi"
    ],
    "week": [
        "mlungu gumamfu"
    ],
    "day": [
        "sihu"
    ],
    "hour": [
        "saa"
    ],
    "minute": [
        "dakika"
    ],
    "second": [
        "sekunde"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "igolo"
        ],
        "0 day ago": [
            "neng'u ni"
        ],
        "in 1 day": [
            "hilawu"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}