# -*- coding: utf-8 -*-
info = {
    "name": "lu",
    "date_order": "DMY",
    "january": [
        "ciongo",
        "cio"
    ],
    "february": [
        "lùishi",
        "lui"
    ],
    "march": [
        "lusòlo",
        "lus"
    ],
    "april": [
        "mùuyà",
        "muu"
    ],
    "may": [
        "lumùngùlù",
        "lum"
    ],
    "june": [
        "lufuimi",
        "luf"
    ],
    "july": [
        "kabàlàshìpù",
        "kab"
    ],
    "august": [
        "lùshìkà",
        "lush"
    ],
    "september": [
        "lutongolo",
        "lut"
    ],
    "october": [
        "lungùdi",
        "lun"
    ],
    "november": [
        "kaswèkèsè",
        "kas"
    ],
    "december": [
        "ciswà",
        "cis"
    ],
    "monday": [
        "nkodya",
        "nko"
    ],
    "tuesday": [
        "ndàayà",
        "ndy"
    ],
    "wednesday": [
        "ndangù",
        "ndg"
    ],
    "thursday": [
        "njòwa",
        "njw"
    ],
    "friday": [
        "ngòvya",
        "ngv"
    ],
    "saturday": [
        "lubingu",
        "lub"
    ],
    "sunday": [
        "lumingu",
        "lum"
    ],
    "am": [
        "dinda"
    ],
    "pm": [
        "dilolo"
    ],
    "year": [
        "tshidimu"
    ],
    "month": [
        "ngondo"
    ],
    "week": [
        "lubingu"
    ],
    "day": [
        "dituku"
    ],
    "hour": [
        "diba"
    ],
    "minute": [
        "kasunsu"
    ],
    "second": [
        "kasunsukusu"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "makelela"
        ],
        "0 day ago": [
            "lelu"
        ],
        "in 1 day": [
            "malaba"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}