# -*- coding: utf-8 -*-
info = {
    "name": "kea",
    "date_order": "DMY",
    "january": [
        "janeru",
        "jan"
    ],
    "february": [
        "febreru",
        "feb"
    ],
    "march": [
        "marsu",
        "mar"
    ],
    "april": [
        "abril",
        "abr"
    ],
    "may": [
        "maiu",
        "mai"
    ],
    "june": [
        "junhu",
        "jun"
    ],
    "july": [
        "julhu",
        "jul"
    ],
    "august": [
        "agostu",
        "ago"
    ],
    "september": [
        "setenbru",
        "set"
    ],
    "october": [
        "otubru",
        "otu"
    ],
    "november": [
        "nuvenbru",
        "nuv"
    ],
    "december": [
        "dizenbru",
        "diz"
    ],
    "monday": [
        "sigunda-fera",
        "sig"
    ],
    "tuesday": [
        "tersa-fera",
        "ter"
    ],
    "wednesday": [
        "kuarta-fera",
        "kua"
    ],
    "thursday": [
        "kinta-fera",
        "kin"
    ],
    "friday": [
        "sesta-fera",
        "ses"
    ],
    "saturday": [
        "sábadu",
        "sab",
        "sabadu"
    ],
    "sunday": [
        "dumingu",
        "dum"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "anu"
    ],
    "month": [
        "mes"
    ],
    "week": [
        "simana",
        "sim"
    ],
    "day": [
        "dia"
    ],
    "hour": [
        "ora",
        "h"
    ],
    "minute": [
        "minutu",
        "min",
        "m"
    ],
    "second": [
        "sigundu",
        "sig",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "anu pasadu"
        ],
        "0 year ago": [
            "es anu li"
        ],
        "in 1 year": [
            "prósimu anu"
        ],
        "1 month ago": [
            "mes pasadu"
        ],
        "0 month ago": [
            "es mes li"
        ],
        "in 1 month": [
            "prósimu mes"
        ],
        "1 week ago": [
            "simana pasadu"
        ],
        "0 week ago": [
            "es simana li"
        ],
        "in 1 week": [
            "prósimu simana"
        ],
        "1 day ago": [
            "onti"
        ],
        "0 day ago": [
            "oji"
        ],
        "in 1 day": [
            "manha"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "di li (\\d+) anu"
        ],
        "\\1 year ago": [
            "a ten (\\d+) anu"
        ],
        "in \\1 month": [
            "di li (\\d+) mes"
        ],
        "\\1 month ago": [
            "a ten (\\d+) mes"
        ],
        "in \\1 week": [
            "di li (\\d+) simana",
            "di li (\\d+) sim"
        ],
        "\\1 week ago": [
            "a ten (\\d+) simana",
            "a ten (\\d+) sim"
        ],
        "in \\1 day": [
            "di li (\\d+) dia"
        ],
        "\\1 day ago": [
            "a ten (\\d+) dia"
        ],
        "in \\1 hour": [
            "di li (\\d+) ora"
        ],
        "\\1 hour ago": [
            "a ten (\\d+) ora"
        ],
        "in \\1 minute": [
            "di li (\\d+) minutu",
            "di li (\\d+) min",
            "di li (\\d+) m"
        ],
        "\\1 minute ago": [
            "a ten (\\d+) minutu",
            "a ten (\\d+) min",
            "a ten (\\d+) m"
        ],
        "in \\1 second": [
            "di li (\\d+) sigundu",
            "di li (\\d+) sig",
            "di li (\\d+) s"
        ],
        "\\1 second ago": [
            "a ten (\\d+) sigundu",
            "a ten (\\d+) sig",
            "a ten (\\d+) s"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}