# -*- coding: utf-8 -*-
info = {
    "name": "mk",
    "date_order": "DMY",
    "january": [
        "јануари",
        "јан"
    ],
    "february": [
        "февруари",
        "фев"
    ],
    "march": [
        "март",
        "мар"
    ],
    "april": [
        "април",
        "апр"
    ],
    "may": [
        "мај"
    ],
    "june": [
        "јуни",
        "јун"
    ],
    "july": [
        "јули",
        "јул"
    ],
    "august": [
        "август",
        "авг"
    ],
    "september": [
        "септември",
        "септ"
    ],
    "october": [
        "октомври",
        "окт"
    ],
    "november": [
        "ноември",
        "ноем"
    ],
    "december": [
        "декември",
        "дек"
    ],
    "monday": [
        "понеделник",
        "пон"
    ],
    "tuesday": [
        "вторник",
        "вто",
        "вт"
    ],
    "wednesday": [
        "среда",
        "сре"
    ],
    "thursday": [
        "четврток",
        "чет"
    ],
    "friday": [
        "петок",
        "пет"
    ],
    "saturday": [
        "сабота",
        "саб"
    ],
    "sunday": [
        "недела",
        "нед"
    ],
    "am": [
        "претпладне",
        "претпл"
    ],
    "pm": [
        "попладне",
        "попл"
    ],
    "year": [
        "година",
        "год"
    ],
    "month": [
        "месец",
        "мес"
    ],
    "week": [
        "недела",
        "сед"
    ],
    "day": [
        "ден"
    ],
    "hour": [
        "час"
    ],
    "minute": [
        "минута",
        "мин"
    ],
    "second": [
        "секунда",
        "сек"
    ],
    "relative-type": {
        "1 year ago": [
            "минатата година"
        ],
        "0 year ago": [
            "оваа година"
        ],
        "in 1 year": [
            "следната година"
        ],
        "1 month ago": [
            "минатиот месец"
        ],
        "0 month ago": [
            "овој месец"
        ],
        "in 1 month": [
            "следниот месец"
        ],
        "1 week ago": [
            "минатата седмица"
        ],
        "0 week ago": [
            "оваа седмица"
        ],
        "in 1 week": [
            "следната седмица"
        ],
        "1 day ago": [
            "вчера"
        ],
        "0 day ago": [
            "денес"
        ],
        "in 1 day": [
            "утре"
        ],
        "0 hour ago": [
            "часов"
        ],
        "0 minute ago": [
            "оваа минута"
        ],
        "0 second ago": [
            "сега"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "за (\\d+) година",
            "за (\\d+) години"
        ],
        "\\1 year ago": [
            "пред (\\d+) година",
            "пред (\\d+) години"
        ],
        "in \\1 month": [
            "за (\\d+) месец",
            "за (\\d+) месеци"
        ],
        "\\1 month ago": [
            "пред (\\d+) месец",
            "пред (\\d+) месеци"
        ],
        "in \\1 week": [
            "за (\\d+) седмица",
            "за (\\d+) седмици"
        ],
        "\\1 week ago": [
            "пред (\\d+) седмица",
            "пред (\\d+) седмици"
        ],
        "in \\1 day": [
            "за (\\d+) ден",
            "за (\\d+) дена"
        ],
        "\\1 day ago": [
            "пред (\\d+) ден",
            "пред (\\d+) дена"
        ],
        "in \\1 hour": [
            "за (\\d+) час",
            "за (\\d+) часа"
        ],
        "\\1 hour ago": [
            "пред (\\d+) час",
            "пред (\\d+) часа"
        ],
        "in \\1 minute": [
            "за (\\d+) минута",
            "за (\\d+) минути"
        ],
        "\\1 minute ago": [
            "пред (\\d+) минута",
            "пред (\\d+) минути"
        ],
        "in \\1 second": [
            "за (\\d+) секунда",
            "за (\\d+) секунди"
        ],
        "\\1 second ago": [
            "пред (\\d+) секунда",
            "пред (\\d+) секунди"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}