# -*- coding: utf-8 -*-
info = {
    "name": "luo",
    "date_order": "DMY",
    "january": [
        "dwe mar achiel",
        "dac"
    ],
    "february": [
        "dwe mar ariyo",
        "dar"
    ],
    "march": [
        "dwe mar adek",
        "dad"
    ],
    "april": [
        "dwe mar ang'wen",
        "dan"
    ],
    "may": [
        "dwe mar abich",
        "dah"
    ],
    "june": [
        "dwe mar auchiel",
        "dau"
    ],
    "july": [
        "dwe mar abiriyo",
        "dao"
    ],
    "august": [
        "dwe mar aboro",
        "dab"
    ],
    "september": [
        "dwe mar ochiko",
        "doc"
    ],
    "october": [
        "dwe mar apar",
        "dap"
    ],
    "november": [
        "dwe mar gi achiel",
        "dgi"
    ],
    "december": [
        "dwe mar apar gi ariyo",
        "dag"
    ],
    "monday": [
        "wuok tich",
        "wut"
    ],
    "tuesday": [
        "tich ariyo",
        "tar"
    ],
    "wednesday": [
        "tich adek",
        "tad"
    ],
    "thursday": [
        "tich ang'wen",
        "tan"
    ],
    "friday": [
        "tich abich",
        "tab"
    ],
    "saturday": [
        "ngeso",
        "ngs"
    ],
    "sunday": [
        "jumapil",
        "jmp"
    ],
    "am": [
        "od"
    ],
    "pm": [
        "ot"
    ],
    "year": [
        "higa"
    ],
    "month": [
        "dwe"
    ],
    "week": [
        "juma"
    ],
    "day": [
        "chieng'"
    ],
    "hour": [
        "saa"
    ],
    "minute": [
        "dakika"
    ],
    "second": [
        "nyiriri mar saa"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "nyoro"
        ],
        "0 day ago": [
            "kawuono"
        ],
        "in 1 day": [
            "kiny"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}