# -*- coding: utf-8 -*-
info = {
    "name": "az-Cyrl",
    "date_order": "DMY",
    "january": [
        "јанвар",
        "јан"
    ],
    "february": [
        "феврал",
        "фев"
    ],
    "march": [
        "март",
        "мар"
    ],
    "april": [
        "апрел",
        "апр"
    ],
    "may": [
        "май"
    ],
    "june": [
        "ијун",
        "ијн"
    ],
    "july": [
        "ијул",
        "ијл"
    ],
    "august": [
        "август",
        "авг"
    ],
    "september": [
        "сентјабр",
        "сен"
    ],
    "october": [
        "октјабр",
        "окт"
    ],
    "november": [
        "нојабр",
        "ној"
    ],
    "december": [
        "декабр",
        "дек"
    ],
    "monday": [
        "базар ертәси",
        "бе"
    ],
    "tuesday": [
        "чәршәнбә ахшамы",
        "ча"
    ],
    "wednesday": [
        "чәршәнбә",
        "ч"
    ],
    "thursday": [
        "ҹүмә ахшамы",
        "ҹа"
    ],
    "friday": [
        "ҹүмә",
        "ҹ"
    ],
    "saturday": [
        "шәнбә",
        "ш"
    ],
    "sunday": [
        "базар",
        "б"
    ],
    "am": [
        "ам"
    ],
    "pm": [
        "пм"
    ],
    "year": [
        "year"
    ],
    "month": [
        "month"
    ],
    "week": [
        "week"
    ],
    "day": [
        "day"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "0 day ago": [
            "today"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}